@@ -5,30 +5,30 @@
 #pragma once
 
 #include <QObject>
-#include <Akonadi/AgentFilterProxyModel>
-#include <Akonadi/CollectionFilterProxyModel>
-#include <Akonadi/ETMViewStateSaver>
-#include <Akonadi/EntityRightsFilterModel>
 
-#include <QObject>
 #include <akonadi-calendar_version.h>
 #if AKONADICALENDAR_VERSION > QT_VERSION_CHECK(5, 19, 41)
+#include <Akonadi/ETMCalendar>
 #include <Akonadi/IncidenceChanger>
 #else
+#include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/Calendar/IncidenceChanger>
 #endif
-#include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
+
+#include <Akonadi/CollectionFilterProxyModel>
 #include <KConfigWatcher>
-#include <KDescendantsProxyModel>
-#include <incidencewrapper.h>
-#include <models/todosortfilterproxymodel.h>
+#include <QObject>
+#include <akonadi-calendar_version.h>
+
+class IncidenceWrapper;
 
 namespace Akonadi
 {
-class ETMCalendar;
+class ETMViewStateSaver;
+class EntityRightsFilterModel;
 }
 
+class KDescendantsProxyModel;
 class KCheckableProxyModel;
 class QAbstractProxyModel;
 class QAbstractItemModel;
@@ -43,15 +43,13 @@ class CalendarManager : public QObject
     Q_PROPERTY(QAbstractItemModel *viewCollections READ viewCollections CONSTANT)
     Q_PROPERTY(QVector<qint64> enabledTodoCollections READ enabledTodoCollections NOTIFY enabledTodoCollectionsChanged)
     Q_PROPERTY(Akonadi::CollectionFilterProxyModel *allCalendars READ allCalendars CONSTANT)
-    Q_PROPERTY(Akonadi::CollectionFilterProxyModel *selectableCalendars READ selectableCalendars CONSTANT)
-    Q_PROPERTY(Akonadi::CollectionFilterProxyModel *selectableEventCalendars READ selectableEventCalendars CONSTANT)
-    Q_PROPERTY(Akonadi::CollectionFilterProxyModel *selectableTodoCalendars READ selectableTodoCalendars CONSTANT)
     Q_PROPERTY(Akonadi::ETMCalendar::Ptr calendar READ calendar CONSTANT)
     Q_PROPERTY(Akonadi::IncidenceChanger *incidenceChanger READ incidenceChanger CONSTANT)
     Q_PROPERTY(QVariantMap undoRedoData READ undoRedoData NOTIFY undoRedoDataChanged)
 
 public:
-    CalendarManager(QObject *parent = nullptr);
+    static CalendarManager *instance();
+    explicit CalendarManager(QObject *parent = nullptr);
     ~CalendarManager() override;
 
     KCheckableProxyModel *collectionSelectionProxyModel() const;
@@ -68,14 +66,13 @@ public:
     Akonadi::ETMCalendar::Ptr calendar() const;
     Akonadi::IncidenceChanger *incidenceChanger() const;
     Akonadi::CollectionFilterProxyModel *allCalendars();
-    Akonadi::CollectionFilterProxyModel *selectableCalendars() const;
-    Akonadi::CollectionFilterProxyModel *selectableEventCalendars() const;
-    Akonadi::CollectionFilterProxyModel *selectableTodoCalendars() const;
     Q_INVOKABLE qint64 defaultCalendarId(IncidenceWrapper *incidenceWrapper);
-    Q_INVOKABLE int getCalendarSelectableIndex(IncidenceWrapper *incidenceWrapper);
     QVariantMap undoRedoData();
 
-    Q_INVOKABLE Akonadi::Item incidenceItem(KCalendarCore::Incidence::Ptr incidence);
+    Q_INVOKABLE Akonadi::Item incidenceItem(KCalendarCore::Incidence::Ptr incidence) const;
+    Akonadi::Item incidenceItem(const QString &uid) const;
+    KCalendarCore::Incidence::List childIncidences(const QString &uid) const;
+
     Q_INVOKABLE void addIncidence(IncidenceWrapper *incidenceWrapper);
     Q_INVOKABLE void editIncidence(IncidenceWrapper *incidenceWrapper);
     Q_INVOKABLE void updateIncidenceDates(IncidenceWrapper *incidenceWrapper,
@@ -89,7 +86,7 @@ public:
     Q_INVOKABLE void changeIncidenceCollection(KCalendarCore::Incidence::Ptr incidence, qint64 collectionId);
     void changeIncidenceCollection(Akonadi::Item item, qint64 collectionId);
     Q_INVOKABLE QVariantMap getCollectionDetails(QVariant collectionId);
-    Q_INVOKABLE void setCollectionColor(qint64 collectionId, QColor color);
+    Q_INVOKABLE void setCollectionColor(qint64 collectionId, const QColor &color);
     Q_INVOKABLE QVariant getIncidenceSubclassed(KCalendarCore::Incidence::Ptr incidencePtr);
     Q_INVOKABLE void undoAction();
     Q_INVOKABLE void redoAction();
@@ -98,23 +95,24 @@ public:
     Q_INVOKABLE void updateCollection(qint64 collectionId);
     Q_INVOKABLE void deleteCollection(qint64 collectionId);
     Q_INVOKABLE void editCollection(qint64 collectionId);
+    Q_INVOKABLE void toggleCollection(qint64 collectionId);
 
 private Q_SLOTS:
     void delayedInit();
 
 Q_SIGNALS:
     void loadingChanged();
-    void entityTreeModelChanged();
+    void calendarChanged();
     void undoRedoDataChanged();
-    void incidenceChanged();
     void enabledTodoCollectionsChanged();
     void updateIncidenceDatesCompleted();
     void collectionColorsChanged();
+    void incidenceAdded();
 
 private:
     Akonadi::ETMCalendar::Ptr m_calendar = nullptr;
-    Akonadi::IncidenceChanger *m_changer;
-    KDescendantsProxyModel *m_flatCollectionTreeModel;
+    Akonadi::IncidenceChanger *m_changer = nullptr;
+    KDescendantsProxyModel *m_flatCollectionTreeModel = nullptr;
     ColorProxyModel *m_baseModel = nullptr;
     KCheckableProxyModel *m_selectionProxyModel = nullptr;
     Akonadi::ETMViewStateSaver *mCollectionSelectionModelStateSaver = nullptr;
@@ -124,9 +122,6 @@ private:
     Akonadi::EntityRightsFilterModel *m_allCollectionsRightsFilterModel = nullptr;
     Akonadi::EntityRightsFilterModel *m_eventRightsFilterModel = nullptr;
     Akonadi::EntityRightsFilterModel *m_todoRightsFilterModel = nullptr;
-    Akonadi::CollectionFilterProxyModel *m_selectableCollectionsModel = nullptr;
-    Akonadi::CollectionFilterProxyModel *m_selectableEventCollectionsModel = nullptr;
-    Akonadi::CollectionFilterProxyModel *m_selectableTodoCollectionsModel = nullptr;
     Akonadi::CollectionFilterProxyModel *m_todoViewCollectionModel = nullptr;
     Akonadi::CollectionFilterProxyModel *m_viewCollectionModel = nullptr;
     QVector<qint64> m_enabledTodoCollections;
