@@ -3,20 +3,23 @@
 
 #pragma once
 
-#include <CalendarSupport/KCalPrefs>
-#include <CalendarSupport/Utils>
-#include <KCalUtils/RecurrenceActions>
-#include <QByteArray>
-#include <QObject>
+#include "calendarmanager.h"
+#include "models/attachmentsmodel.h"
+#include "models/attendeesmodel.h"
+#include "models/recurrenceexceptionsmodel.h"
+#include "models/remindersmodel.h"
+
 #include <Akonadi/CollectionIdentificationAttribute>
 #include <Akonadi/Item>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/ItemMonitor>
-#include "models/attachmentsmodel.h"
-#include "models/attendeesmodel.h"
-#include "models/recurrenceexceptionsmodel.h"
-#include "models/remindersmodel.h"
+#include <CalendarSupport/KCalPrefs>
+#include <CalendarSupport/Utils>
+#include <KCalUtils/RecurrenceActions>
+#include <KFormat>
+#include <QByteArray>
+#include <QObject>
 
 /**
  * This class is a wrapper for a KCalendarCore::Incidence::Ptr object.
@@ -29,23 +32,33 @@
 class IncidenceWrapper : public QObject, public Akonadi::ItemMonitor
 {
     Q_OBJECT
+
+    // Akonadi properties
     Q_PROPERTY(Akonadi::Item incidenceItem READ incidenceItem WRITE setIncidenceItem NOTIFY incidenceItemChanged)
     Q_PROPERTY(KCalendarCore::Incidence::Ptr incidencePtr READ incidencePtr WRITE setIncidencePtr NOTIFY incidencePtrChanged)
+    Q_PROPERTY(qint64 collectionId READ collectionId WRITE setCollectionId NOTIFY collectionIdChanged)
+
+    // Incidence properties
+    Q_PROPERTY(KCalendarCore::Incidence::Ptr incidencePtr READ incidencePtr WRITE setIncidencePtr NOTIFY incidencePtrChanged)
     Q_PROPERTY(KCalendarCore::Incidence::Ptr originalIncidencePtr READ originalIncidencePtr NOTIFY originalIncidencePtrChanged)
     Q_PROPERTY(int incidenceType READ incidenceType NOTIFY incidenceTypeChanged)
     Q_PROPERTY(QString incidenceTypeStr READ incidenceTypeStr NOTIFY incidenceTypeStrChanged)
     Q_PROPERTY(QString incidenceIconName READ incidenceIconName NOTIFY incidenceIconNameChanged)
+    Q_PROPERTY(QString uid READ uid CONSTANT) // TODO: This needs to not be a CONSTANT
+    Q_PROPERTY(qint64 collectionId READ collectionId WRITE setCollectionId NOTIFY collectionIdChanged)
     Q_PROPERTY(QString uid READ uid CONSTANT)
 
-    Q_PROPERTY(qint64 collectionId READ collectionId WRITE setCollectionId NOTIFY collectionIdChanged)
     Q_PROPERTY(QString parent READ parent WRITE setParent NOTIFY parentChanged)
+    Q_PROPERTY(IncidenceWrapper *parentIncidence READ parentIncidence NOTIFY parentIncidenceChanged)
+    Q_PROPERTY(QVariantList childIncidences READ childIncidences NOTIFY childIncidencesChanged)
+
     Q_PROPERTY(QString summary READ summary WRITE setSummary NOTIFY summaryChanged)
     Q_PROPERTY(QStringList categories READ categories WRITE setCategories NOTIFY categoriesChanged)
     Q_PROPERTY(QString description READ description WRITE setDescription NOTIFY descriptionChanged)
     Q_PROPERTY(QString location READ location WRITE setLocation NOTIFY locationChanged)
-    Q_PROPERTY(bool hasGeo READ hasGeo CONSTANT)
-    Q_PROPERTY(float geoLatitude READ geoLatitude CONSTANT)
-    Q_PROPERTY(float geoLongitude READ geoLongitude CONSTANT)
+    Q_PROPERTY(bool hasGeo READ hasGeo CONSTANT) // TODO: This needs to not be a CONSTANT
+    Q_PROPERTY(float geoLatitude READ geoLatitude CONSTANT) // TODO: This needs to not be a CONSTANT
+    Q_PROPERTY(float geoLongitude READ geoLongitude CONSTANT) // TODO: This needs to not be a CONSTANT
 
     Q_PROPERTY(QDateTime incidenceStart READ incidenceStart WRITE setIncidenceStart NOTIFY incidenceStartChanged)
     Q_PROPERTY(QString incidenceStartDateDisplay READ incidenceStartDateDisplay NOTIFY incidenceStartDateDisplayChanged)
@@ -56,6 +69,8 @@ class IncidenceWrapper : public QObject, public Akonadi::ItemMonitor
     Q_PROPERTY(QByteArray timeZone READ timeZone WRITE setTimeZone NOTIFY timeZoneChanged)
     Q_PROPERTY(int startTimeZoneUTCOffsetMins READ startTimeZoneUTCOffsetMins NOTIFY startTimeZoneUTCOffsetMinsChanged)
     Q_PROPERTY(int endTimeZoneUTCOffsetMins READ endTimeZoneUTCOffsetMins NOTIFY endTimeZoneUTCOffsetMinsChanged)
+    Q_PROPERTY(KCalendarCore::Duration duration READ duration NOTIFY durationChanged)
+    Q_PROPERTY(QString durationDisplayString READ durationDisplayString NOTIFY durationDisplayStringChanged)
     Q_PROPERTY(bool allDay READ allDay WRITE setAllDay NOTIFY allDayChanged)
     Q_PROPERTY(int priority READ priority WRITE setPriority NOTIFY priorityChanged)
 
@@ -81,7 +96,7 @@ public:
         Monthly,
         Yearly,
     };
-    Q_ENUM(RecurrenceIntervals);
+    Q_ENUM(RecurrenceIntervals)
 
     enum IncidenceTypes {
         TypeEvent = KCalendarCore::IncidenceBase::TypeEvent,
@@ -97,7 +112,9 @@ public:
     };
     Q_ENUM(RecurrenceActions)
 
-    IncidenceWrapper(QObject *parent = nullptr);
+    typedef QSharedPointer<IncidenceWrapper> Ptr;
+
+    explicit IncidenceWrapper(QObject *parent = nullptr);
     ~IncidenceWrapper() override;
 
     void notifyDataChanged();
@@ -105,7 +122,6 @@ public:
     Akonadi::Item incidenceItem() const;
     void setIncidenceItem(const Akonadi::Item &incidenceItem);
     KCalendarCore::Incidence::Ptr incidencePtr() const;
-    void setIncidencePtr(KCalendarCore::Incidence::Ptr incidencePtr);
     KCalendarCore::Incidence::Ptr originalIncidencePtr();
     int incidenceType() const;
     QString incidenceTypeStr() const;
@@ -115,6 +131,9 @@ public:
     void setCollectionId(qint64 collectionId);
     QString parent() const;
     void setParent(QString parent);
+    IncidenceWrapper *parentIncidence();
+    QVariantList childIncidences();
+
     QString summary() const;
     void setSummary(const QString &summary);
     QStringList categories();
@@ -144,6 +163,8 @@ public:
     void setTimeZone(const QByteArray &timeZone);
     int startTimeZoneUTCOffsetMins();
     int endTimeZoneUTCOffsetMins();
+    KCalendarCore::Duration duration() const;
+    QString durationDisplayString() const;
     bool allDay() const;
     void setAllDay(bool allDay);
     int priority() const;
@@ -176,6 +197,7 @@ public:
     Q_INVOKABLE void setRecurrenceOccurrences(int occurrences);
     Q_INVOKABLE void clearRecurrences();
 
+    Q_INVOKABLE void setCollection(const Akonadi::Collection &collection);
 Q_SIGNALS:
     void incidenceItemChanged();
     void incidencePtrChanged(KCalendarCore::Incidence::Ptr incidencePtr);
@@ -185,10 +207,14 @@ Q_SIGNALS:
     void incidenceIconNameChanged();
     void collectionIdChanged();
     void parentChanged();
+    void parentIncidenceChanged();
+    void childIncidencesChanged();
+
     void summaryChanged();
     void categoriesChanged();
     void descriptionChanged();
     void locationChanged();
+
     void incidenceStartChanged();
     void incidenceStartDateDisplayChanged();
     void incidenceStartTimeDisplayChanged();
@@ -198,14 +224,18 @@ Q_SIGNALS:
     void timeZoneChanged();
     void startTimeZoneUTCOffsetMinsChanged();
     void endTimeZoneUTCOffsetMinsChanged();
+    void durationChanged();
+    void durationDisplayStringChanged();
     void allDayChanged();
     void priorityChanged();
+
     void remindersModelChanged();
     void recurrenceDataChanged();
     void organizerChanged();
     void attendeesModelChanged();
     void recurrenceExceptionsModelChanged();
     void attachmentsModelChanged();
+
     void todoCompletedChanged();
     void todoCompletionDtChanged();
     void todoPercentCompleteChanged();
@@ -215,7 +245,11 @@ protected:
     void itemChanged(const Akonadi::Item &item) override;
 
 private:
+    void setIncidencePtr(KCalendarCore::Incidence::Ptr incidencePtr);
     void setNewIncidence(KCalendarCore::Incidence::Ptr incidence);
+    void updateParentIncidence();
+    void resetChildIncidences();
+    void cleanupChildIncidences();
 
     KCalendarCore::Incidence::Ptr m_incidence;
     KCalendarCore::Incidence::Ptr m_originalIncidence;
@@ -224,4 +258,8 @@ private:
     AttendeesModel m_attendeesModel;
     RecurrenceExceptionsModel m_recurrenceExceptionsModel;
     AttachmentsModel m_attachmentsModel;
+
+    KFormat m_format;
+    Ptr m_parentIncidence;
+    QVariantList m_childIncidences;
 };
