@@ -22,7 +22,6 @@
 #include <QMenu>
 #include <QQuickWindow>
 #include <QSortFilterProxyModel>
-#include <QWindow>
 #include <vector>
 
 KalendarApplication::KalendarApplication(QObject *parent)
@@ -157,6 +156,22 @@ void KalendarApplication::setupActions()
         mCollection.setDefaultShortcut(openScheduleAction, QKeySequence(i18n("Ctrl+5")));
     }
 
+    actionName = QLatin1String("open_contact_view");
+    if (KAuthorized::authorizeAction(actionName)) {
+        auto openContactAction = mCollection.addAction(actionName, this, &KalendarApplication::openContactView);
+        openContactAction->setText(i18n("Contacts View"));
+        openContactAction->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-contacts")));
+        openContactAction->setCheckable(true);
+        openContactAction->setActionGroup(m_viewGroup);
+        connect(openContactAction, &QAction::toggled, this, [](bool checked) {
+            if (checked) {
+                KalendarConfig::setLastOpenedView(KalendarConfig::ContactView);
+                KalendarConfig::self()->save();
+            }
+        });
+        mCollection.setDefaultShortcut(openContactAction, QKeySequence(i18n("Ctrl+5")));
+    }
+
     actionName = QLatin1String("open_month_view");
     if (KAuthorized::authorizeAction(actionName)) {
         auto openMonthAction = mCollection.addAction(actionName, this, &KalendarApplication::openMonthView);
@@ -411,10 +426,10 @@ void KalendarApplication::setupActions()
         mCollection.setDefaultShortcut(openKCommandBarAction, QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_I));
     }
 
-    actionName = QLatin1String("refresh_all_calendars");
+    actionName = QLatin1String("refresh_all");
     if (KAuthorized::authorizeAction(actionName)) {
-        auto refreshAllAction = mCollection.addAction(actionName, this, &KalendarApplication::refreshAllCalendars);
-        refreshAllAction->setText(i18n("Refresh All Calendars"));
+        auto refreshAllAction = mCollection.addAction(actionName, this, &KalendarApplication::refreshAll);
+        refreshAllAction->setText(i18n("Refresh All"));
         refreshAllAction->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
 
         mCollection.addAction(refreshAllAction->objectName(), refreshAllAction);
