@@ -2,7 +2,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "todosortfilterproxymodel.h"
-#include <KFormat>
 
 TodoSortFilterProxyModel::TodoSortFilterProxyModel(QObject *parent)
     : QSortFilterProxyModel(parent)
@@ -93,7 +92,11 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
     }
 
     auto collectionId = todoItem.parentCollection().id();
+#if AKONADICALENDAR_VERSION < QT_VERSION_CHECK(5, 20, 42)
     auto todoPtr = CalendarSupport::todo(todoItem);
+#else
+    auto todoPtr = Akonadi::CalendarUtils::todo(todoItem);
+#endif
 
     if (!todoPtr) {
         return {};
@@ -117,11 +120,15 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
     } else if (role == Roles::CollectionIdRole) {
         return collectionId;
     } else if (role == DurationStringRole) {
-        KFormat format;
-        if (todoPtr->allDay()) {
-            return format.formatSpelloutDuration(24 * 60 * 60 * 1000); // format milliseconds in 1 day
+        const auto duration = KCalendarCore::Duration(todoPtr->dtStart(), todoPtr->dtDue());
+
+        if (todoPtr->allDay() && !todoPtr->dtStart().isValid()) {
+            return m_format.formatSpelloutDuration(24 * 60 * 60 * 1000); // format milliseconds in 1 day
+        } else if (!todoPtr->dtStart().isValid() || duration.asSeconds() == 0) {
+            return QString();
         }
-        return format.formatSpelloutDuration(todoPtr->duration().asSeconds() * 1000);
+
+        return m_format.formatSpelloutDuration(duration.asSeconds() * 1000);
     } else if (role == Roles::RecursRole) {
         return todoPtr->recurs();
     } else if (role == Roles::IsOverdueRole) {
@@ -135,7 +142,11 @@ QVariant TodoSortFilterProxyModel::data(const QModelIndex &index, int role) cons
     } else if (role == Roles::IncidenceTypeIconRole) {
         return todoPtr->iconName();
     } else if (role == Roles::IncidencePtrRole) {
+#if AKONADICALENDAR_VERSION < QT_VERSION_CHECK(5, 20, 42)
         return QVariant::fromValue(CalendarSupport::incidence(todoItem));
+#else
+        return QVariant::fromValue(Akonadi::CalendarUtils::incidence(todoItem));
+#endif
     } else if (role == Roles::TagsRole) {
         return QVariant::fromValue(todoItem.tags());
     } else if (role == Roles::ItemRole) {
@@ -222,7 +233,7 @@ bool TodoSortFilterProxyModel::filterAcceptsRowCheck(int row, const QModelIndex
     }
 
     if (m_filterMap.contains(QLatin1String("tags")) && !m_filterMap[QLatin1String("tags")].toStringList().isEmpty()) {
-        auto tags = m_filterMap[QLatin1String("tags")].toStringList();
+        const auto tags = m_filterMap[QLatin1String("tags")].toStringList();
         bool containsTag = false;
         for (const auto &tag : tags) {
             const auto todoPtr = sourceIndex.data(TodoModel::TodoPtrRole).value<KCalendarCore::Todo::Ptr>();
@@ -306,7 +317,7 @@ void TodoSortFilterProxyModel::loadColors()
     Q_EMIT layoutChanged();
 }
 
-int TodoSortFilterProxyModel::showCompleted()
+int TodoSortFilterProxyModel::showCompleted() const
 {
     return m_showCompleted;
 }
@@ -323,7 +334,7 @@ void TodoSortFilterProxyModel::setShowCompleted(int showCompleted)
     sortTodoModel();
 }
 
-QVariantMap TodoSortFilterProxyModel::filterMap()
+QVariantMap TodoSortFilterProxyModel::filterMap() const
 {
     return m_filterMap;
 }
@@ -337,7 +348,7 @@ void TodoSortFilterProxyModel::setFilterMap(const QVariantMap &filterMap)
     Q_EMIT filterMapChanged();
 
     if (m_filterMap.contains(QLatin1String("name"))) {
-        auto name = m_filterMap[QLatin1String("name")].toString();
+        const auto name = m_filterMap[QLatin1String("name")].toString();
         setFilterFixedString(name);
     }
     invalidateFilter();
@@ -348,7 +359,7 @@ void TodoSortFilterProxyModel::setFilterMap(const QVariantMap &filterMap)
 
 void TodoSortFilterProxyModel::sortTodoModel()
 {
-    auto order = m_sortAscending ? Qt::AscendingOrder : Qt::DescendingOrder;
+    const auto order = m_sortAscending ? Qt::AscendingOrder : Qt::DescendingOrder;
     QSortFilterProxyModel::sort(m_sortColumn, order);
 }
 
@@ -356,7 +367,7 @@ void TodoSortFilterProxyModel::filterTodoName(QString name, int showCompleted)
 {
     Q_EMIT layoutAboutToBeChanged();
     setFilterFixedString(name);
-    if (name.length() > 0) {
+    if (!name.isEmpty()) {
         m_showCompleted = showCompleted;
     } else {
         setShowCompleted(m_showCompletedStore);
@@ -601,7 +612,7 @@ bool TodoSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelInd
     }
 }
 
-int TodoSortFilterProxyModel::sortBy()
+int TodoSortFilterProxyModel::sortBy() const
 {
     return m_sortColumn;
 }
@@ -613,7 +624,7 @@ void TodoSortFilterProxyModel::setSortBy(int sortBy)
     sortTodoModel();
 }
 
-bool TodoSortFilterProxyModel::sortAscending()
+bool TodoSortFilterProxyModel::sortAscending() const
 {
     return m_sortAscending;
 }
@@ -625,7 +636,7 @@ void TodoSortFilterProxyModel::setSortAscending(bool sortAscending)
     sortTodoModel();
 }
 
-bool TodoSortFilterProxyModel::showCompletedSubtodosInIncomplete()
+bool TodoSortFilterProxyModel::showCompletedSubtodosInIncomplete() const
 {
     return m_showCompletedSubtodosInIncomplete;
 }
